@@ -1,20 +1,6 @@
 // sockstream.C -*- C++ -*- socket library
 // Copyright (C) 2002 Herbert Straub for my changes, see ChangeLog.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-// 
 // Copyright (C) 1992-1996 Gnanasekaran Swaminathan <gs4t@virginia.edu>
 //
 // Permission is granted to use at your own risk and distribute this software
@@ -59,6 +45,7 @@
 // Version: 1.2 2002-07-25 Herbert Straub 
 // 	Improved Error Handling - extending the sockerr class by cOperation
 
+using namespace std;
 
 #include <config.h>
 #include <socket++/sockstream.h>
@@ -565,12 +552,13 @@ int sockbuf::write(const void* buf, int len)
 // upon error, write throws the number of bytes writen so far instead
 // of sockerr.
 {
+  char *pbuf = (char*) buf;
   if (rep->stmo != -1 && is_writeready (rep->stmo)==0)
     throw sockerr (ETIMEDOUT, "sockbuf::write", sockname.c_str());
   
   int wlen=0;
   while(len>0) {
-    int	wval = ::write (rep->sock, (char*) buf, len);
+    int	wval = ::write (rep->sock, pbuf+wlen, len);
     if (wval == -1) throw wlen;
     len -= wval;
     wlen += wval;
@@ -582,12 +570,13 @@ int sockbuf::send (const void* buf, int len, int msgf)
 // upon error, write throws the number of bytes writen so far instead
 // of sockerr.
 {
+  char *pbuf = (char *) buf;
   if (rep->stmo != -1 && is_writeready (rep->stmo)==0)
     throw sockerr (ETIMEDOUT, "sockbuf::send", sockname.c_str());
   
   int wlen=0;
   while(len>0) {
-    int	wval = ::send (rep->sock, (char*) buf, len, msgf);
+    int	wval = ::send (rep->sock, pbuf+wlen, len, msgf);
     if (wval == -1) throw wlen;
     len -= wval;
     wlen += wval;
@@ -599,12 +588,13 @@ int sockbuf::sendto (sockAddr& sa, const void* buf, int len, int msgf)
 // upon error, write throws the number of bytes writen so far instead
 // of sockerr.
 {
+  char *pbuf = (char *) buf;
   if (rep->stmo != -1 && is_writeready (rep->stmo)==0)
     throw sockerr (ETIMEDOUT, "sockbuf::sendto", sockname.c_str());
   
   int wlen=0;
   while(len>0) {
-    int	wval = ::sendto (rep->sock, (char*) buf, len, msgf,
+    int	wval = ::sendto (rep->sock, pbuf+wlen, len, msgf,
 			 sa.addr (), sa.size());
     if (wval == -1) throw wlen;
     len -= wval;
